@@ -9,6 +9,7 @@ class Config:
     :param file_path: The path to the YAML configuration file.
     :type file_path: str
     """
+
     def __init__(self, file_path: str):
         self.file_path = file_path
         self.config = self.load_config(file_path)
@@ -37,6 +38,37 @@ class Config:
             raise FileNotFoundError("Config file not found")
         except yaml.YAMLError as e:
             raise ValueError(f"Error parsing config file: {str(e)}")
+        
+    @property
+    def input_format(self) -> str:
+        """
+        Get the input file format configuration dictionary.
+
+        :returns: A string containing the input file type
+        :rtype: str
+
+        :raises ValueError: If the "input_format" key is not present in the configuration dictionary.
+        """
+        try:
+            return self.config["input_format"]
+        except KeyError:
+            raise ValueError("input file format not found in config file")
+        
+    @property
+    def output_format(self) -> str:
+        """
+        Get the output file format configuration dictionary.
+
+        :returns: A string containing the output file type
+        :rtype: str
+
+        :raises ValueError: If the "output_format" key is not present in the configuration dictionary.
+        """
+        try:
+            return self.config["output_format"]
+        except KeyError:
+            raise ValueError("output file format not found in config file")
+
 
     @property
     def cleaning_config(self) -> Dict:
